@@ -1,3 +1,5 @@
+use std::time::Duration;
+
 use clap::{App, Arg};
 
 mod error;
@@ -9,10 +11,10 @@ use crate::logger::Logger;
 use crate::waitz::Waitz;
 
 fn main() -> Result<()> {
-    let matches = App::new("waitz")
-        .version("0.2.0")
-        .author("Max Strübing <mxstrbng@gmail.com>")
-        .about("Waits until the exit code of a program is zero")
+    let matches = App::new(env!("CARGO_PKG_NAME"))
+        .about(env!("CARGO_PKG_DESCRIPTION"))
+        .author(env!("CARGO_PKG_AUTHORS"))
+        .version(env!("CARGO_PKG_VERSION"))
         .arg(
             Arg::with_name("interval")
                 .long("interval")
@@ -31,13 +33,23 @@ fn main() -> Result<()> {
                 .required(false)
                 .help("Don't try to rerun the command in case it fails with non-zero exit code"),
         )
+        .arg(
+            Arg::with_name("max-retries")
+                .long("max-retries")
+                .short("r")
+                .value_name("max-retries")
+                .takes_value(true)
+                .required(false)
+                .default_value("0")
+                .help("Positive integer how often the command should be retried"),
+        )
         .arg(
             Arg::with_name("verbose")
                 .long("verbose")
                 .value_name("verbose")
                 .takes_value(false)
                 .required(false)
-                .help("Outputs verbose information"),
+                .help("Forwards stdout/stderr from the command to the terminal"),
         )
         .arg(
             Arg::with_name("debug")
@@ -57,16 +69,25 @@ fn main() -> Result<()> {
 
     let verbose = matches.is_present("verbose");
     let debug = matches.is_present("debug");
+
     let logger = Logger { verbose, debug };
 
-    logger.debug(&format!("Got args: {:?}", matches));
+    logger.debug(&format!("Arguments: {:?}", matches));
 
     let interval = matches
         .value_of("interval")
         .ok_or_else(|| Error::NoneError("Could not get interval".to_owned()))?
         .parse::<u64>()?;
 
-    let no_retry = matches.is_present("no-retry");
+    let mut max_retries = matches
+        .value_of("max-retries")
+        .ok_or_else(|| Error::NoneError("Could not get max retries".to_owned()))?
+        .parse::<u64>()?;
+
+    // no-retry has precedence
+    if matches.is_present("no-retry") {
+        max_retries = 1
+    }
 
     let mut original_args = matches
         .values_of("COMMAND")
@@ -81,8 +102,8 @@ fn main() -> Result<()> {
     let waitz = Waitz {
         command,
         args,
-        interval,
-        no_retry,
+        interval: Duration::from_millis(interval),
+        max_retries,
         logger,
     };
 
